auto_paginated_list library

Classes

AutoPaginatedList<T>
A widget that displays a paginated list and loads more data as the user scrolls.
PaginationState<T>
Manages pagination state for the AutoPaginatedList widget.

Typedefs

FetchMoreItems<T> = Future<List<T>> Function(int page)
Signature for a function that fetches more items of type T given a page number.
ItemBuilder<T> = Widget Function(BuildContext context, T item)
Signature for a function that builds a widget given a BuildContext and an item of type T.